# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/classifieds/advertisings/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/classifieds/advertisings/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Classifieds\\Advertisings\\": "packages/classifieds/advertisings/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Classifieds\Advertisings\Providers\AdvertisingsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Advertisings'  => Classifieds\Advertisings\Facades\Advertisings::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Classifieds\\AdvertisingsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Classifieds\Advertisings\Providers\AdvertisingsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Classifieds\Advertisings\Providers\AdvertisingsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Classifieds\Advertisings\Providers\AdvertisingsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/advertisings/{modulename}

**User**

    http://path-to-route-folder/user/advertisings/{modulename}

**Public**

    http://path-to-route-folder/advertisings


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/advertisings/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/advertisings/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/advertisings/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/advertisings/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/advertisings/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/advertisings/{modulename}/{slug}
    METHOD: GET