<?php

namespace Classifieds\Advertisings\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Classifieds\Advertisings\Interfaces\AdvertisingRepositoryInterface;

class AdvertisingPublicController extends BaseController
{
    // use AdvertisingWorkflow;

    /**
     * Constructor.
     *
     * @param type \Classifieds\Advertising\Interfaces\AdvertisingRepositoryInterface $advertising
     *
     * @return type
     */
    public function __construct(AdvertisingRepositoryInterface $advertising)
    {
        $this->repository = $advertising;
        parent::__construct();
    }

    /**
     * Show advertising's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $advertisings = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('advertisings::advertising.names'))
            ->view('advertisings::public.advertising.index')
            ->data(compact('advertisings'))
            ->output();
    }


    /**
     * Show advertising.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $advertising = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($advertising->name . trans('advertisings::advertising.name'))
            ->view('advertisings::public.advertising.show')
            ->data(compact('advertising'))
            ->output();
    }

}
