<?php

namespace Classifieds\Advertisings\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Classifieds\Advertisings\Interfaces\FavoriteRepositoryInterface;

class FavoritePublicController extends BaseController
{
    // use FavoriteWorkflow;

    /**
     * Constructor.
     *
     * @param type \Classifieds\Favorite\Interfaces\FavoriteRepositoryInterface $favorite
     *
     * @return type
     */
    public function __construct(FavoriteRepositoryInterface $favorite)
    {
        $this->repository = $favorite;
        parent::__construct();
    }

    /**
     * Show favorite's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $favorites = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('advertisings::favorite.names'))
            ->view('advertisings::public.favorite.index')
            ->data(compact('favorites'))
            ->output();
    }


    /**
     * Show favorite.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $favorite = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($favorite->name . trans('advertisings::favorite.name'))
            ->view('advertisings::public.favorite.show')
            ->data(compact('favorite'))
            ->output();
    }

}
