<?php

namespace Classifieds\Advertisings\Policies;

use Litepie\User\Contracts\UserPolicy;
use Classifieds\Advertisings\Models\Advertising;

class AdvertisingPolicy
{

    /**
     * Determine if the given user can view the advertising.
     *
     * @param UserPolicy $user
     * @param Advertising $advertising
     *
     * @return bool
     */
    public function view(UserPolicy $user, Advertising $advertising)
    {
        if ($user->canDo('advertisings.advertising.view') && $user->isAdmin()) {
            return true;
        }

        return $advertising->user_id == user_id() && $advertising->user_type == user_type();
    }

    /**
     * Determine if the given user can create a advertising.
     *
     * @param UserPolicy $user
     * @param Advertising $advertising
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advertisings.advertising.create');
    }

    /**
     * Determine if the given user can update the given advertising.
     *
     * @param UserPolicy $user
     * @param Advertising $advertising
     *
     * @return bool
     */
    public function update(UserPolicy $user, Advertising $advertising)
    {
        if ($user->canDo('advertisings.advertising.edit') && $user->isAdmin()) {
            return true;
        }

        return $advertising->user_id == user_id() && $advertising->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given advertising.
     *
     * @param UserPolicy $user
     * @param Advertising $advertising
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Advertising $advertising)
    {
        return $advertising->user_id == user_id() && $advertising->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given advertising.
     *
     * @param UserPolicy $user
     * @param Advertising $advertising
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Advertising $advertising)
    {
        if ($user->canDo('advertisings.advertising.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given advertising.
     *
     * @param UserPolicy $user
     * @param Advertising $advertising
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Advertising $advertising)
    {
        if ($user->canDo('advertisings.advertising.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
