<?php

namespace Classifieds\Advertisings\Policies;

use Litepie\User\Contracts\UserPolicy;
use Classifieds\Advertisings\Models\Favorite;

class FavoritePolicy
{

    /**
     * Determine if the given user can view the favorite.
     *
     * @param UserPolicy $user
     * @param Favorite $favorite
     *
     * @return bool
     */
    public function view(UserPolicy $user, Favorite $favorite)
    {
        if ($user->canDo('advertisings.favorite.view') && $user->isAdmin()) {
            return true;
        }

        return $favorite->user_id == user_id() && $favorite->user_type == user_type();
    }

    /**
     * Determine if the given user can create a favorite.
     *
     * @param UserPolicy $user
     * @param Favorite $favorite
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advertisings.favorite.create');
    }

    /**
     * Determine if the given user can update the given favorite.
     *
     * @param UserPolicy $user
     * @param Favorite $favorite
     *
     * @return bool
     */
    public function update(UserPolicy $user, Favorite $favorite)
    {
        if ($user->canDo('advertisings.favorite.edit') && $user->isAdmin()) {
            return true;
        }

        return $favorite->user_id == user_id() && $favorite->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given favorite.
     *
     * @param UserPolicy $user
     * @param Favorite $favorite
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Favorite $favorite)
    {
        return $favorite->user_id == user_id() && $favorite->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given favorite.
     *
     * @param UserPolicy $user
     * @param Favorite $favorite
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Favorite $favorite)
    {
        if ($user->canDo('advertisings.favorite.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given favorite.
     *
     * @param UserPolicy $user
     * @param Favorite $favorite
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Favorite $favorite)
    {
        if ($user->canDo('advertisings.favorite.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
